==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DelaySpecFluent<A extends DelaySpecFluent<A>> extends BaseFluent<A>{
  public DelaySpecFluent() {
  }
  
  public DelaySpecFluent(DelaySpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String jitter;
  private String latency;
  private ReorderSpecBuilder reorder;
  
  protected void copyInstance(DelaySpec instance) {
    instance = (instance != null ? instance : new DelaySpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withJitter(instance.getJitter());
        this.withLatency(instance.getLatency());
        this.withReorder(instance.getReorder());
        this.withCorrelation(instance.getCorrelation());
        this.withJitter(instance.getJitter());
        this.withLatency(instance.getLatency());
        this.withReorder(instance.getReorder());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getJitter() {
    return this.jitter;
  }
  
  public A withJitter(String jitter) {
    this.jitter=jitter; return (A) this;
  }
  
  public boolean hasJitter() {
    return this.jitter != null;
  }
  
  public String getLatency() {
    return this.latency;
  }
  
  public A withLatency(String latency) {
    this.latency=latency; return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public ReorderSpec buildReorder() {
    return this.reorder!=null ?this.reorder.build():null;
  }
  
  public A withReorder(ReorderSpec reorder) {
    _visitables.get("reorder").remove(this.reorder);
    if (reorder!=null){ this.reorder= new ReorderSpecBuilder(reorder); _visitables.get("reorder").add(this.reorder);} else { this.reorder = null; _visitables.get("reorder").remove(this.reorder); } return (A) this;
  }
  
  public boolean hasReorder() {
    return this.reorder != null;
  }
  
  public A withNewReorder(String correlation,Integer gap,String reorder) {
    return (A)withReorder(new ReorderSpec(correlation, gap, reorder));
  }
  
  public ReorderNested<A> withNewReorder() {
    return new ReorderNested(null);
  }
  
  public ReorderNested<A> withNewReorderLike(ReorderSpec item) {
    return new ReorderNested(item);
  }
  
  public ReorderNested<A> editReorder() {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(null));
  }
  
  public ReorderNested<A> editOrNewReorder() {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(new ReorderSpecBuilder().build()));
  }
  
  public ReorderNested<A> editOrNewReorderLike(ReorderSpec item) {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DelaySpecFluent that = (DelaySpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(jitter, that.jitter)) return false;
  
    if (!java.util.Objects.equals(latency, that.latency)) return false;
  
    if (!java.util.Objects.equals(reorder, that.reorder)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  jitter,  latency,  reorder,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (jitter != null) { sb.append("jitter:"); sb.append(jitter + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (reorder != null) { sb.append("reorder:"); sb.append(reorder); }
    sb.append("}");
    return sb.toString();
  }
  public class ReorderNested<N> extends ReorderSpecFluent<ReorderNested<N>> implements Nested<N>{
    ReorderNested(ReorderSpec item) {
      this.builder = new ReorderSpecBuilder(this, item);
    }
    ReorderSpecBuilder builder;
    
    public N and() {
      return (N) DelaySpecFluent.this.withReorder(builder.build());
    }
    
    public N endReorder() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/DelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DelaySpecFluent<A extends DelaySpecFluent<A>> extends BaseFluent<A>{
  public DelaySpecFluent() {
  }
  
  public DelaySpecFluent(DelaySpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String jitter;
  private String latency;
  private ReorderSpecBuilder reorder;
  
  protected void copyInstance(DelaySpec instance) {
    instance = (instance != null ? instance : new DelaySpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withJitter(instance.getJitter());
          this.withLatency(instance.getLatency());
          this.withReorder(instance.getReorder());
          this.withCorrelation(instance.getCorrelation());
          this.withJitter(instance.getJitter());
          this.withLatency(instance.getLatency());
          this.withReorder(instance.getReorder());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getJitter() {
    return this.jitter;
  }
  
  public A withJitter(String jitter) {
    this.jitter = jitter;
    return (A) this;
  }
  
  public boolean hasJitter() {
    return this.jitter != null;
  }
  
  public String getLatency() {
    return this.latency;
  }
  
  public A withLatency(String latency) {
    this.latency = latency;
    return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public ReorderSpec buildReorder() {
    return this.reorder != null ? this.reorder.build() : null;
  }
  
  public A withReorder(ReorderSpec reorder) {
    this._visitables.remove(this.reorder);
    if (reorder != null) {
        this.reorder = new ReorderSpecBuilder(reorder);
        this._visitables.get("reorder").add(this.reorder);
    } else {
        this.reorder = null;
        this._visitables.get("reorder").remove(this.reorder);
    }
    return (A) this;
  }
  
  public boolean hasReorder() {
    return this.reorder != null;
  }
  
  public A withNewReorder(String correlation,Integer gap,String reorder) {
    return (A)withReorder(new ReorderSpec(correlation, gap, reorder));
  }
  
  public ReorderNested<A> withNewReorder() {
    return new ReorderNested(null);
  }
  
  public ReorderNested<A> withNewReorderLike(ReorderSpec item) {
    return new ReorderNested(item);
  }
  
  public ReorderNested<A> editReorder() {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(null));
  }
  
  public ReorderNested<A> editOrNewReorder() {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(new ReorderSpecBuilder().build()));
  }
  
  public ReorderNested<A> editOrNewReorderLike(ReorderSpec item) {
    return withNewReorderLike(java.util.Optional.ofNullable(buildReorder()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DelaySpecFluent that = (DelaySpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(jitter, that.jitter)) return false;
    if (!java.util.Objects.equals(latency, that.latency)) return false;
    if (!java.util.Objects.equals(reorder, that.reorder)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  jitter,  latency,  reorder,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (jitter != null) { sb.append("jitter:"); sb.append(jitter + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (reorder != null) { sb.append("reorder:"); sb.append(reorder); }
    sb.append("}");
    return sb.toString();
  }
  public class ReorderNested<N> extends ReorderSpecFluent<ReorderNested<N>> implements Nested<N>{
    ReorderNested(ReorderSpec item) {
      this.builder = new ReorderSpecBuilder(this, item);
    }
    ReorderSpecBuilder builder;
    
    public N and() {
      return (N) DelaySpecFluent.this.withReorder(builder.build());
    }
    
    public N endReorder() {
      return and();
    }
    
  
  }

}
